Skip to main contentModule input
Source - In
- Input specification with cardinality and optional guard predicate.
- all
- Consume all available tokens (must be 1+).
- all_guarded
- Consume all available tokens matching the guard.
- at_least
- Wait for N+ tokens, consume all when enabled.
- at_least_guarded
- Wait for N+ tokens matching guard, consume all when enabled.
- consumption_count
- Returns the actual number of tokens to consume given the available count.
- exactly
- Consume exactly N tokens from the place.
- exactly_guarded
- Consume exactly N tokens matching the guard.
- one
- Consume exactly 1 token from the place.
- one_guarded
- Consume exactly 1 token matching the guard.
- required_count
- Returns the minimum number of tokens required to enable.
- GuardFn
- Type-erased guard function.