consumption_count

Function consumption_count 

pub fn consumption_count(spec: &In, available: usize) -> usize
Returns the actual number of tokens to consume given the available count.

Panics

Panics if available is less than the required count.