pub struct Place<T: 'static> { /* private fields */ }Expand description
A typed place in the Petri Net that holds tokens of a specific type.
Places are the “state containers” of a Petri net. They hold tokens that represent data or resources flowing through the net.
Places use name-based equality. Clone is cheap (Arc
Implementations